mriqc package — mriqc 0.8 documentation

# mriqc package

## Subpackages

- mriqc.interfaces package
  - Submodules
  - mriqc.interfaces.qc module
  - mriqc.interfaces.viz module
  - mriqc.interfaces.viz_utils module
  - Module contents
- mriqc.qc package
  - Module contents
  - Submodules
  - mriqc.qc.anatomical module
  - mriqc.qc.functional module
- The MRIQC Reports
  - Structural images (sMRI)
    - For the individual scan reports:
    - For the group reports:
  - Functional images (fMRI)
- mriqc.reports package
  - Submodules
  - mriqc.reports.generators module
  - mriqc.reports.utils module
  - Module contents
- mriqc.utils package
  - Submodules
  - mriqc.utils.misc module
  - Module contents
- mriqc.workflows package
  - Submodules
  - mriqc.workflows.anatomical module
  - mriqc.workflows.core module
  - mriqc.workflows.functional module
  - mriqc.workflows.utils module
  - Module contents

## Submodules

## mriqc.run_mriqc module

### MRIQC

`mriqc.run_mriqc.` `main`()

  Entry point

## Module contents

The mriqc package provides a series of NR, IQMs to used in QAPs for MRI.

### Dependencies

Make sure you have FSL and AFNI installed, and the binaries available in the system’s $PATH.

### Installation

The easiest path is using pypi

    pip install mriqc

### Example

    mriqc bids_dataset/ output_folder/ participant